function [power1,power2,power8]=Orden(f,n,m,puntos,a,b)

% Esta funcin calcula la reconstruccin de una curva por PPH
% en un intervalo dado en el que los puntos estarn equiespaciados.
%
% [power1]=Orden(f,n,m,puntos,a,b)
%
% Variables de entrada:
% f           Funcin que se quiere discretizar
% n           Nmero de veces a realizar la reconstruccin
% m           Nmero de puntos de divisin del intervalo (a,b)
% puntos      Nmero de puntos de divisin del intervalo (0,1)
% (a,b)       Intervalo en el que queremos calcular la reconstruccin
%
%
% Variables de salida:
% power1     Vector del orden de la reconstruccin usando error con norma 1
% power2     Vector del orden de la reconstruccin usando error con norma 2
% power8     Vector del orden de la reconstruccin usando error con norma
%            infinito
%
% Ejemplo:
% [power1,power2,power8]=Orden('sin(x)',5,10,100,0,pi);


err_vector=zeros(n,1);
power1=zeros(n-1,1);
power2=zeros(n-1,1);
power8=zeros(n-1,1);

for i=1:n
    
    [pol,Error1,Error2,Error8]=PPHvi_funcion(f,m,puntos,a,b);
    
    err_vector1(i)=Error1;
    err_vector2(i)=Error2;
    err_vector8(i)=Error8;
    
    m=m*2;
    
end

% Clculo del vector del orden
for i=1:n-1
    power1(i)=log2(err_vector1(i)/err_vector1(i+1));
    power2(i)=log2(err_vector2(i)/err_vector2(i+1));
    power8(i)=log2(err_vector8(i)/err_vector8(i+1));
end     

err_vector1
err_vector2
err_vector8


% Se dibujan los datos iniciales
figure('Name','ERRORES EN LA RECONSTRUCCIN')
Merr=max(err_vector1);
derr=Merr/10;
g1=plot(err_vector1,'ob-','MarkerSize',3,'LineWidth',2);
hold on
g2=plot(err_vector2,'or-','MarkerSize',3,'LineWidth',2);
g8=plot(err_vector8,'og-','MarkerSize',3,'LineWidth',2);
legend('Error1','Error2','Error8');
axis([0 n 0 Merr+derr]);
grid on
xlabel('Fase'),ylabel('Error')
title('Reconstruccin PPH')

% Se dibujan los datos iniciales
figure('Name','ORDEN DE LA RECONSTRUCCIN')
Morden=max(power8);
morden=min(power1);
g1=plot(power1,'ob-','MarkerSize',3,'LineWidth',2);
hold on
g2=plot(power2,'or-','MarkerSize',3,'LineWidth',2);
g8=plot(power8,'og-','MarkerSize',3,'LineWidth',2);
axis([0 n morden-0.5 Morden+0.5]);
grid on
xlabel('Fase'),ylabel('Orden')
legend('Power1','Power2','Power8');
title('Reconstruccin PPH')


end





