function [pol]=PPH(Z,puntos,a,b)

% Esta funcin calcula la reconstruccin de una curva por PPH
% en un intervalo dado en el que los puntos estarn equiespaciados.
%
% [pol]=PPH(Z,puntos,a,b)
%
% Variables de entrada:
% Z             Vector de ordenadas de los puntos del intervalo (a,b)
% puntos        Nmero de puntos de subdivisin del intervalo (0,1)
% (a,b)         Intervalo en el que queremos calcular la reconstruccin
%
% Variables de salida:
% pol           Valor del nuevo polinomio en la reconstruccin por PPH
%
% Ejemplo:
% [pol]=PPH(Z,30,-1,2);


puntos=round(puntos);


% Se muestra mensaje de error si n es cero o negativo
if puntos<=0
    error('Nmero de puntos de subdivisin del intervalo incorrecto. Por favor, introduzca una cifra positiva')
end


% Se calcula el numero de elementos de vector Z
longZ= length(Z);


% Se calcula la separacin entre puntos
h=abs(b-a)/(longZ-1);


% Se muestra mensaje de notificacin del espaciado entre puntos de X
sprintf('El espaciado entre los puntos de abscisas es: ')
h


% Se inicializa el vector de abscisas X a cero
X=zeros(longZ,1);


% Se calculan las abscisas del vector X
X=linspace(a,b,longZ)

% Se visualiza el vector X
sprintf('Vector de abscisas:')
X


% Se divide el intervalo (0,1) en n puntos en los que se reconstruir
% el polinomio p(t)
T=linspace(0,1,puntos);


% se calculan las diferencias divididas
delta0=Z(1)-2*Z(2)+Z(3);
delta1=Z(2)-2*Z(3)+Z(4);


% Se calculan los valores del polinomio en el intervalo (X(2),X(3)) para
% cada caso
if delta0*delta1>0
    A= -2*delta0*delta1^2*(5*delta0+delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
    B= -2*delta0^2*delta1*(delta0+5*delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
    pol=Z(2)*(1-T)+Z(3)*T+T.*(1-T).*(A*T+B*(1-T));
else
    pol=Z(2)*(1-T)+Z(3)*T;
end


% Visualizacin de los valores del polinomio de reconstruccin en los 
% extremos del intervalo para comprobar que coinciden con los valores de Z(2) y Z(3)
sprintf('Valor del polinomio en el extremo izquierdo del intervalo:')
pol(1)
sprintf('Valor del polinomio en el extremo derecho del intervalo:')
pol(puntos)


% Se escala el vector T segn la distancia entre abscisas
T=linspace(X(2),X(3),puntos);


% Visualizacin en forma de grfica de las ordenadas Z(i) como de todos los
% valores del polinomio de reconstruccin entre X(2) y X(3)
plot(X,Z,'ob:','MarkerSize',5); 
hold on
plot(T,pol,'r','LineWidth',2);
grid on
xlabel('x'),ylabel('Z')
title('Reconstruccin PPH')
   

end
