function [pol,Error1,Error2,Error8]=PPH_funcion(f,puntos,a,b)

% Esta funcin calcula la reconstruccin de una curva por PPH
% en un intervalo dado en el que los puntos estarn equiespaciados.
%
% [pol,Error]=PPH_funcion(f,puntos,a,b)
%
% Variables de entrada:
% f             Funcin a reconstruir 
% puntos        Nmero de puntos de subdivisin del intervalo (0,1)
% (a,b)         Intervalo en el que queremos calcular la reconstruccin
%
% Variables de salida:
% pol           Valor del nuevo polinomio en la reconstruccin por PPH
% Error         Error entre la funcin discretizada y la reconstruccin.
%
% Ejemplo:
% [pol,Error]=PPH_funcion('sin(x)',30,0,pi);



% Discretizacin de la funcin en el intervalo con el nmero de puntos
% requeridos -> Z contiene los valores reales de la funcin.
X=linspace(a,b,4);
Z=subs(f,X);


% Se dibujan los datos iniciales
figure('Name','Reconstruccin PPH')
mx=min(X); Mx=max(X);
mz=min(Z); Mz=max(Z);
dx=(Mx-mx)/5;
dz=(Mz-mz)/5;
g1=plot(X,Z,'ob:','MarkerSize',3);
axis([mx-dx Mx+dx mz-dz Mz+dz]);
hold on
grid on
xlabel('x'),ylabel('Z')
title('Reconstruccin PPH')


% Se divide el intervalo (0,1) en n puntos en los que se reconstruir
% el polinomio pol(T)
T=linspace(0,1,puntos);


% Se divide el intervalo correspondiente de la funcin f en el mismo
% nmero de puntos donde se va a calcular la reconstruccin para poder
% calcular su valore real y proceder a calcular el error.
Xreal=linspace(X(2),X(3),puntos);  
    
    
% se calculan las diferencias divididas
delta0=Z(1)-2*Z(2)+Z(3);
delta1=Z(2)-2*Z(3)+Z(4);


% Inicializacin del error y las traslacin
Error=0;
Tras=0;


% Se calculan los valores del polinomio en el intervalo (X(2),((3)) para
% cada caso
if delta0*delta1>0
    A= -2*delta0*delta1^2*(5*delta0+delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
    B= -2*delta0^2*delta1*(delta0+5*delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
    pol=Z(2)*(1-T)+Z(3)*T+T.*(1-T).*(A*T+B*(1-T));
    Zreal=subs(f,Xreal);
elseif delta0*delta1<0 % Si hay cambio de signo entre delta0 y delta1 se procede a realizar traslacin
    display('Traslacin')
    Tras= 2*sign(min(delta0,delta1))*min(delta0,delta1)+sign(max(delta0,delta1))
    A= (5*delta0*delta1+delta1^2+2*delta0*Tras+4*delta1*Tras)*(delta1*Tras+delta0*(2*delta1+Tras))/(delta0^3+delta0^2*(11*delta1+8*Tras)+delta1*(delta1^2+8*delta1*Tras+12*Tras^2)+delta0*(11*delta1^2+32*delta1*Tras+12*Tras^2));
    B= (delta0^2+5*delta0*delta1+4*delta0*Tras+2*delta1*Tras)*(delta1*Tras+delta0*(2*delta1+Tras))/(delta0^3+delta0^2*(11*delta1+8*Tras)+delta1*(delta1^2+8*delta1*Tras+12*Tras^2)+delta0*(11*delta1^2+32*delta1*Tras+12*Tras^2));
    pol=Z(2)*(1-T)+Z(3)*T+T.*(1-T).*(A*T+B*(1-T));
    Zreal=subs(f,Xreal);
else
    pol=Z(2)*(1-T)+Z(3)*T;
    Zreal=subs(f,Xreal);
end


% Clculo del error:
Error=norm(Zreal-pol,1)/puntos;

% Visualizacin en forma de grfica de las ordenadas Z(i) como de todos los
% valores del polinomio de reconstruccin entre X(2) y X(3)
plot(Xreal,pol,'r','LineWidth',2);
 
 
end
