function [pol,Error1,Error2,Error8]=PPHvi_funcion(f,m,puntos,a,b)

% Esta funcin calcula la reconstruccin de una curva por PPH
% en un intervalo dado en el que los puntos estarn equiespaciados.
%
% [pol,Error1,Error2,Error8]=PPHvi_funcion(f,m,puntos,a,b)
%
% Variables de entrada:
% f          Funcin a reconstruir
% m          Nmero de puntos de divisin del intervalo (a,b)
% puntos     Nmero de puntos de subdivisin del intervalo (0,1)
% (a,b)      Intervalo en el que queremos calcular la reconstruccin
%
% Variables de salida:
% pol       Valor del nuevo polinomio en la reconstruccin por PPH
% Error1    Error en norma 1 entre la funcin discretizada y la reconstruccin
% Error2    Error en norma 2 entre la funcin discretizada y la reconstruccin
% Error8    Error en norma infinito entre la funcin discretizada y la reconstruccin
%
% Ejemplo:
% [pol,Error1,Error2,Error8]=PPHvi_funcion('sin(x)',30,100,0,pi);



% Discretizacin de la funcin en el intervalo con el nmero de puntos
% requeridos -> Z contiene los valores reales de la funcin.
X=linspace(a,b,m);
Z=subs(f,X);


% Se inicializan a ceros los vectores Xaux y Zaux que facilitan el
% clculo progresivo de los trozos polinmicos
Xaux=zeros(4,1);
Zaux=zeros(4,1);


% Inicializacin de la variable de traslacin.
Tras=0;


% Inicializacin de las variables de error
Error1=0;
Error2=0;
Error8=0;


% % Dibujamos los datos iniciales
% figure('Name','Reconstruccin PPH')
% mx=min(X); Mx=max(X);
% mz=min(Z); Mz=max(Z);
% dx=(Mx-mx)/10;
% dz=(Mz-mz)/10;
% g1=plot(X,Z,'ob:','MarkerSize',3);
% axis([mx-dx Mx+dx mz-dz Mz+dz]);
% hold on
% grid on
% xlabel('x'),ylabel('Z')
% title('Reconstruccin PPH')


% Comienza el bucle que controla el intervalo de clculo
for intervalo=1:m-3

    Xaux=X(intervalo:intervalo+3);
    Zaux=Z(intervalo:intervalo+3);

    
    % Se divide el intervalo (0,1) en "puntos" en los que se reconstruir
    % el polinomio pol(T)
    T=linspace(0,1,puntos);
    
    
    % Se divide el intervalo correspondiente de la funcin f en el mismo
    % nmero de puntos donde se va a calcular la reconstruccin para poder
    % calcular su valore real y proceder a calcular el error.
    Xreal=linspace(Xaux(2),Xaux(3),puntos);  

    
    % se calculan las diferencias divididas
    delta0=Zaux(1)-2*Zaux(2)+Zaux(3);
    delta1=Zaux(2)-2*Zaux(3)+Zaux(4);

    
    % Se calculan los valores del polinomio en el intervalo (X(2),X(3)) para
    % cada caso
    if delta0*delta1>0
        
        display('Delta0')
        delta0
        display('Delta1')
        delta1
        A= -2*delta0*delta1^2*(5*delta0+delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
        B= -2*delta0^2*delta1*(delta0+5*delta1)/((delta0+delta1)*(delta0^2+10*delta0*delta1+delta1^2));
        pol=Zaux(2)*(1-T)+Zaux(3)*T+T.*(1-T).*(A*T+B*(1-T));
        Zreal=subs(f,Xreal);
    elseif delta0*delta1<0 | (delta0==0 & delta1 ~= 0) | (delta1==0 & delta0 ~=0) 
        % Si hay cambio de signo entre delta0 y delta1, o si slo uno de los dos
        % es cero, se procede a realizar traslacin         
        display('Traslacin')
        Tras=Traslacion(delta0,delta1)
        display('Delta0')
        delta0
        display('Delta1')
        delta1
        A= -(5*delta0*delta1+delta1^2+2*delta0*Tras+4*delta1*Tras)*(delta1*Tras+delta0*(2*delta1+Tras))/(delta0^3+delta0^2*(11*delta1+8*Tras)+delta1*(delta1^2+8*delta1*Tras+12*Tras^2)+delta0*(11*delta1^2+32*delta1*Tras+12*Tras^2));
        B= -(delta0^2+5*delta0*delta1+4*delta0*Tras+2*delta1*Tras)*(delta1*Tras+delta0*(2*delta1+Tras))/(delta0^3+delta0^2*(11*delta1+8*Tras)+delta1*(delta1^2+8*delta1*Tras+12*Tras^2)+delta0*(11*delta1^2+32*delta1*Tras+12*Tras^2));
        pol=Zaux(2)*(1-T)+Zaux(3)*T+T.*(1-T).*(A*T+B*(1-T));
        Zreal=subs(f,Xreal);
    else
        display('Se da el caso')
        pol=Zaux(2)*(1-T)+Zaux(3)*T;
        Zreal=subs(f,Xreal);
    end
    
    
    % Se mide el error entre la funcin discretizada y la reconstruccin
    % Se tiene en cuenta que al valor de la reconstruccin (pol) habr que
    % restarle el valor de la traslacin (Tras).
    Error1=Error1+norm(Zreal-pol,1);
    Error2=Error2+norm(Zreal-pol,2);
    Error8=max(Error8,norm(Zreal-pol,Inf));
    
    
    % Se escala el vector T segn la distancia entre abscisas
    T=linspace(Xaux(2),Xaux(3),puntos);

    
%     % Visualizacin en forma de grfica de las ordenadas Z(i) como de todos los
%     % valores del polinomio de reconstruccin entre X(2) y X(3)
%     plot(T,pol,'r','LineWidth',2);
%     legend('Funcin Real','Reconstruccin');
%     pause(1)
    
 
end

Error1=Error1/((puntos-3)*m-(puntos-6));
Error2=Error2/((puntos-3)*m-(puntos-6));
%Error8=Error8/((puntos-3)*m-(puntos-6));

end
